# iKISS {.unnumbered}

Congratulations! iKISS was successfully ran. Check results through this report!

iKISS (Kmer Inference sSelection) is a snakemake pipeline able to decompose reads into kmers and extract kmers under selection.

It's available on [gitlab](https://forge.ird.fr/DIADE/iKISS)

Licenced under MIT.

Intellectual property belongs to authors and IRD.


